@@ -20,14 +20,18 @@ def fake_data_generator(conf: List[dict]) -> pd.DataFrame:
     # First create all the lines with the cartesian product of all the
     # possible values of 'label' columns
     label_confs = [x for x in conf if x['type'] == 'label']
-    label_names = [x['name'] for x in label_confs]
-    label_values = [x['values'] for x in label_confs]
+    label_names = [x.get('name', 'Unnamed') for x in label_confs]
+    label_values = [x.get('values', []) for x in label_confs]
     df = pd.DataFrame(list(product(*label_values)), columns=label_names)
 
     # Then add all the 'number' columns
     number_confs = [x for x in conf if x['type'] == 'number']
     for num_conf in number_confs:
-        num_column = np.random.uniform(low=num_conf['min'], high=num_conf['max'], size=df.shape[0])
-        df[num_conf['name']] = num_column.round(num_conf.get('digits', 4))
+        num_column = np.random.uniform(
+            low=num_conf.get('min', 0),
+            high=num_conf.get('max', num_conf.get('min', 0) + 10),
+            size=df.shape[0],
+        )
+        df[num_conf.get('name', 'Unnamed')] = num_column.round(num_conf.get('digits', 4))
 
     return df
